Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(216)

Unified Diff: lib/src/utils.dart

Issue 1034303003: Consistently use "OS" rather than "Os" in identifiers. (Closed) Base URL: git@github.com:dart-lang/unittest@master
Patch Set: Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | lib/unittest.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: lib/src/utils.dart
diff --git a/lib/src/utils.dart b/lib/src/utils.dart
index 2a12238932ded4d1533bd5c9b34f3094e3012713..05a0c4dbc0425f93e3a55f7ca15ab252607bb506 100644
--- a/lib/src/utils.dart
+++ b/lib/src/utils.dart
@@ -22,8 +22,8 @@ final _exceptionPrefix = new RegExp(r'^([A-Z][a-zA-Z]*)?(Exception|Error): ');
/// Directories that are specific to OS X.
///
-/// This is used to try to distinguish OS X and Linux in [currentOsGuess].
-final _macOsDirectories = new Set<String>.from([
+/// This is used to try to distinguish OS X and Linux in [currentOSGuess].
+final _macOSDirectories = new Set<String>.from([
"/Applications",
"/Library",
"/Network",
@@ -37,10 +37,10 @@ final _macOsDirectories = new Set<String>.from([
/// This is useful for running test files directly and skipping tests as
/// appropriate. The only OS-specific information we have is the current path,
/// which we try to use to figure out the OS.
-final OperatingSystem currentOsGuess = (() {
+final OperatingSystem currentOSGuess = (() {
if (p.style == p.Style.url) return OperatingSystem.none;
if (p.style == p.Style.windows) return OperatingSystem.windows;
- if (_macOsDirectories.any(p.current.startsWith)) return OperatingSystem.macOs;
+ if (_macOSDirectories.any(p.current.startsWith)) return OperatingSystem.macOS;
return OperatingSystem.linux;
})();
« no previous file with comments | « no previous file | lib/unittest.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698